"""."""

# 定义抽取结果的名字
OUTPUT = "result.csv"

# 状态机状态
START = 0  # 开始状态
TITLE = 1  # 抽取文书title信息
TYPE = 2  # 抽取类型信息
NUMBER = 3  # 案号信息
YUANGAO = 4  # 原告信息
BEIGAO = 5  # 被告信息
PARTY = 10  # 新版，当事人，取代原告，被告，第三人
THIRD_PERSON = 6  # 第三人信息
CONTENT = 7  # 抽取文书内容信息
FOOTER = 8  # 抽取文书落款信息
END = 9  # 结束信息

CASE_DOMAIN = ["民事", "行政", "刑事", "执行"]  # 案件类型
LAW_TYPE = ["裁决书", "判决书", "裁定书", "调解书"]  # 文书类型
PARTIES_STOP = ["申诉人", "反诉原告", "原告人", "原告",
                "上诉单位", "本诉原告", "上诉人", "公诉机关", "再审申请人", "起诉人", "申请人",
                "申请再审人", "自诉人", "复议申请人", "附带民事诉讼原告人", "申请执行人", "申请追加人",
                "解除保全申请人", "原告1", "原告2", "原告3", "异议人", "申请复议人"]
PARTIES_YG = ["原审上诉人", "申诉人", "原审原告", "反诉原告", "一审原告", "原告人",
              "上诉单位", "本诉原告", "上诉人", "公诉机关", "再审申请人", "起诉人", "申请人",
              "申请再审人", "自诉人", "复议申请人", "附带民事诉讼原告人", "申请执行人", "申请追加人",
              "解除保全申请人", "再审上诉人", "原告1", "原告2", "原告3", "原告一", "原告二",
              "原告三", "原告",
              "异议人", "申请复议人", "申请执行机关", "申请执行", "申请复议人", "案外人"]
PARTIES_BG = ["原审被上诉人", "被申诉人", "被上诉人", "被诉人", "再审被申请人", "被申请人",
              "原上诉人", "被起诉人", "本诉被告", "原公诉机关", "原审被告", "反诉被告",
              "一审被告", "被告人", "附带民事诉讼被告人", "被执行人", "被申请追加人", "罪犯",
              "再审被上诉人", "被告1", "被告2", "被告3", "被告一", "被告二", "被告三", "被告"]
PARTIES_DSR = ["一审第三人", "原审第三人", "反诉第三人", "第三人", "第三",
               "一审原告、二审上诉人", "一审原告、二审被上诉人", "一审被告、二审上诉人", "一审被告、二审被上诉人",
               "一审第三人、二审上诉人", "一审第三人、二审被上诉人"]

PARTIES = []  # 当事人信息
PARTIES.extend(PARTIES_YG)
PARTIES.extend(PARTIES_BG)
PARTIES.extend(PARTIES_DSR)

LEGAL = ["定代表人", "法等代表人", "法定代笔人", "法定代表人", "法定代表", "法定代理人",
         "法定代人", "法定借助人", "法人代表人", "法人代表"]
PRINCIPAL = ["全权代表", "授权代表", "授权经理人", "授权签署人", "授权签字代表",
             "授权签字人", "授权人", "义乌办事处首席代表", "代表人", "负责人", "委托代理", "代理人",
             "诉讼代表人", "委托代表人"]  # 授权代表
OTHERS = ["监护人", "经营者", "投资人", "执行合伙企业事务的合伙人", "执行合伙人", "执行合伙事务合伙人",
          "执行事务合伙人", "专家辅助人", "翻译人员", "法定代理人", "业主"]  # 其他
PROXY = ["辩护人", "委托代理人", "委托人", "委托人理人", "诉讼代理人",
         "委托地利人", "委托大理人", "委托诉讼代理人", "委托代付"]  # 诉讼代理人
RELATIVES = []
RELATIVES.extend(PROXY)
RELATIVES.extend(PRINCIPAL)
RELATIVES.extend(OTHERS)
RELATIVES.extend(LEGAL)

ROLES = ["经营者", "审判长", "代理审判员", "书记员", "人民陪审员"]  # 所有角色
ROLES.extend(PARTIES)
ROLES.extend(RELATIVES)
AFFAIR = ["经营者", "法定代表人", "委托代理人"]
FOOTER_ROLE = ["审判长", "代理审判长", "审判员", "代理审判员",
               "人民陪审员", "法官助理", "书记员", "速录员"]  # 落款处角色信息
PUNCTUATION = set([u"，u", u"。", u"？", u"！", u"：u", u"；"])
PUNCTUATION_ALL = set([u"，", u"。", u"？", u"！", u"：",
                       u"；", ",", "?", "!", ":", ";"])
LINE_COUNT = 0
DICT = {}  # 字典
CHINESE_NUM = {"一": 1, "二": 2, "三": 3, "四": 4, "五": 5, "六": 6, "七": 7, "八": 8,
               "九": 9, "十": 10, "两": 2, "十一": 11, "十二": 12, "十三": 13,
               "十四": 14, "十五": 15}
NUMBERS = ["一", "二", "三", "四", "五", "六", "七", "八", "九",
           "十", "1", "2", "3", "4", "5", "6", "7", "8", "9"]

# 正则
JUDGE_PATTERN = "(裁决|裁定|判决)(如下|)(:|：)"  # 判决如下
YEAR_MONTH_DATE = "(\\d+)年(\\d+)月(\\d+)(日|)"  # 人物出生日期
# 案号正则
ANHAO = "(\(|\[|（|【|〔|（|)(\d+)(\)|\]|】|〕|）|)(.{3,40})([\d、\-—xX]+)(号)(之一)?"
# 案号正则
YISHENANHAO = "(\(|\[|（|【|〔|（|)(\d+)(\)|\]|】|〕|）|)(.{5,40})(\d+)"
YISHENANHAO += "(号)(之一)?(民事|行政|)(判决|裁定|)"
ANHAO_YEAR = "\d{4}"  # 案号里年份
TRADEMARK_ID = "商评字(\(|\[|（|【|〔)(\d+)(\)|\]|）|】|〕)第(\d+)号"  # 商评字
PATENT_ID = "(专利复审委员会|知识产权局)(.+)第((\d|\.)+)号专利"  # 专利号
FOOTER_YEAR_MONTH_DATE = "(.+)年(.+)月(.+)日"  # 落款日期
# 第三人和被告/原告share共同代理人的情况, %s是角色
COMMON_ROLES_PATTERN1 = '(被告|原告|第三人|上诉人|被上诉人|原审被告|原审原告|原审第三人|)'
COMMON_ROLES_PATTERN1 += '(和|,|，|、|与|)(被告|原告|第三人|上诉人|被上诉人|原审被告|原审原告|原审第三人|)'
COMMON_ROLES_PATTERN1 += '(|之|的)(共同|)%s'
# 上述(以上)x人共同代表人
COMMON_ROLES_PATTERN2 = '(一|二|两|三|四|五|六|七|八|九|十])?(人|%s)(|之|的)%s'
YISHEN_MIN_PAN = ["(驳回(.{0,30})(诉讼|本诉)请求|的(诉讼|本诉)请求不予支持)", "驳回原告诉讼请求"]
YISHEN_MIN_CAI = []
YISHEN_MIN_CAI_1 = ["(按撤诉处理|按(.{0,20})(撤回|撤销)(起诉|反诉|本诉|诉讼)处理)", "按撤诉处理"]
YISHEN_MIN_CAI_2 = ["((撤回|撤销)(.{0,10})(起诉|反诉|本诉|诉讼)|撤诉)", "撤诉"]
YISHEN_MIN_CAI_3 = ["(驳回(.{0,20})起诉|诉讼|反诉|本诉)", "驳回起诉"]
YISHEN_MIN_CAI_4 = ["(不予受理|不予立案)", "不予受理"]
YISHEN_MIN_CAI_5 = ["中止(诉讼|审理)", "中止诉讼"]
YISHEN_MIN_CAI_6 = ["恢复(诉讼|审理)", "恢复审理"]
YISHEN_MIN_CAI_7 = ["驳回(.{0,10})管辖(权|)异议", "驳回管辖权异议"]
YISHEN_MIN_CAI_8 = ["(扣押|冻结|查封|保全|禁令)", "保全程序"]
YISHEN_MIN_CAI_9 = ["本案(指定|(交|)由)(,{0,10})人民法院(审理|管辖)", "指定审理"]
YISHEN_MIN_CAI_10 = ["并入(.{1,30})号案", "并案审理"]
YISHEN_MIN_CAI_11 = ["(另立案号|另案审理|分(为|立)(二|两|三|四|五|六|七|八|九|十)(件|)案)", "分案审理"]
YISHEN_MIN_CAI.append(YISHEN_MIN_CAI_1)
YISHEN_MIN_CAI.append(YISHEN_MIN_CAI_2)
YISHEN_MIN_CAI.append(YISHEN_MIN_CAI_3)
YISHEN_MIN_CAI.append(YISHEN_MIN_CAI_4)
YISHEN_MIN_CAI.append(YISHEN_MIN_CAI_5)
YISHEN_MIN_CAI.append(YISHEN_MIN_CAI_6)
YISHEN_MIN_CAI.append(YISHEN_MIN_CAI_7)
YISHEN_MIN_CAI.append(YISHEN_MIN_CAI_8)
YISHEN_MIN_CAI.append(YISHEN_MIN_CAI_9)
YISHEN_MIN_CAI.append(YISHEN_MIN_CAI_10)
YISHEN_MIN_CAI.append(YISHEN_MIN_CAI_11)
# 正则 Jokers
PATENT_NUMBER = '((ZL|CN|)[ 0-9０－９Xx×Ｘｘ＊*]{8,12}\.[0-9０－９XxＸｘ×＊×])'
TRADEMARK_NUMBER = '(诉争商标|引证商标)?\w*第([0-9]+)号[^，。；、：]*?商标\w*'

ERSHEN_MIN_PAN = []
ERSHEN_MIN_PAN_1 = ["撤销(.{1,10})号(民事判决|原审判决|一审判决)", "撤销一审判决"]
ERSHEN_MIN_PAN_2 = ["(维持原判|维持原审判决|维持一审判决|维持+号民事判决)", "维持一审判决"]
ERSHEN_MIN_PAN.append(ERSHEN_MIN_PAN_1)
ERSHEN_MIN_PAN.append(ERSHEN_MIN_PAN_2)
ERSHEN_XING_PAN = []
ERSHEN_XING_PAN_1 = ["(驳回上诉(.+)维持一审判决|维持原审判决)", "维持一审判决"]
ERSHEN_XING_PAN.append(ERSHEN_XING_PAN_1)

ERSHEN_CAI = []
ERSHEN_XING_CAI_1 = ["(维持原裁定|维持一审裁定|维持原审裁定)", "维持一审裁定"]
ERSHEN_XING_CAI_2 = ["撤销(.+)裁定", "撤销一审裁定"]
ERSHEN_XING_CAI_3 = ["(撤销(.+)判决)(.+)发回(.+)(重审|重新审理)", "撤销一审判决，发回一审重新审理"]
ERSHEN_XING_CAI_4 = ["(撤销(.+)判决)(.+)(驳回(.+)起诉)", "撤销一审判决，驳回原告起诉"]
ERSHEN_XING_CAI_5 = ["(撤回(.+)起诉|撤回(.+)上诉|撤诉)", "撤诉"]
ERSHEN_XING_CAI_6 = ["(恢复诉讼|恢复审理)", "恢复审理"]
ERSHEN_CAI.append(ERSHEN_XING_CAI_1)
ERSHEN_CAI.append(ERSHEN_XING_CAI_2)
ERSHEN_CAI.append(ERSHEN_XING_CAI_3)
ERSHEN_CAI.append(ERSHEN_XING_CAI_4)
ERSHEN_CAI.append(ERSHEN_XING_CAI_5)
ERSHEN_CAI.append(ERSHEN_XING_CAI_6)
# 关键词
SUMMARY = ["不服", "受理", "本院", "原告", "被告"]  # 总结段落的启发词语
END_JUDGE = ["提起上诉", "受理费"]  # 判决结果结束标志
# 民族正则
NATION = "^(汉|哈尼|保安|白|阿昌|布朗|布依|朝鲜|达斡尔|傣|德昂|东乡|侗|独龙"
NATION += "|鄂伦春|俄罗斯|鄂温克|高山|仡佬|哈萨克|赫哲|回|基诺|景颇|京|柯尔克孜|拉祜|"
NATION += "珞巴|僳僳|黎|满|毛南|门巴|蒙古|苗|仫佬|纳西|怒|普米|羌|撒拉|畲|水|塔吉克|"
NATION += "塔塔尔|土家|土|佤|维吾尔|乌孜别克|锡伯|瑶|彝|裕固|藏|壮)族?$"
# 职务正则
POSITION = "副?总?(董事长|无业|新闻资源合作专员|登记注册科科员|法律事务科科员|合伙事务执行人|技术资产所有人|\
总制片人经营人|产业部负责人|法律事务人员|IT工程师|保护科科长|党委副书记|法定代表人|法规股股长|法务部经理|\
法政科科员|高级工程师|个体工商户|合伙执行人|技术部部长|迁西代理商|商标代理人|事务协调员|首席财务官|首席技术官|\
首席运营官|首席执行官|授权签字人|药品注册员|职业摄影师|专利代理人|专利工程师|财务人员|财务总监|代表理事|\
党委书记|党组书记|法律顾问|法律顺间|法务专员|副董事长|副理事长|副调研员|副研究员|副总代表|高级记者|工作人员|\
管理部长|高级管理人员|管理人员|行政副总|行政管理|行政人员|行政助理|行政专员|技术副总|技术人员|技术总监|经销商户|律师助理|\
内容总监|企管人员|人事专员|社长助理|实习律师|事务专员|首席摄影|授权代表|授权官员|维权专员|文职人员|项目经理|\
销售代表|运营总监|支部书记|执行懂事|指导老师|总裁助理|总工程师|总机械师|总设计师|财务长|承包人|出资人|代理人|\
代理商|法律部负责人|负责人|复审员|副部长|副区长|副书记|副团长|副镇长|副政委|助理副总裁|副总裁|工程师|管理员|合伙人|技术员|经营者|\
理事长|配镜师|评审员|评审审查员|审查员|投资人|业务员|营业员|执行官|总编辑|总干事|总指挥|编辑|法律部部长|\
助理部长|部长|财务|厂长|场长|处长|\
代表|店员|店长|店主|执行董事|董事|队长|法律|法人|法务|副理|副总|评审干部|退休干部|干部|工人|股东|股长|\
知识产权顾问|顾问|雇员|馆长|行长|会计|会员|会长\
|监事|教师|教授|经理|局长|科员|科长|课长|矿长|老师|理事|律师|助理秘书|秘书|区长|社长|所长|台长|团长|网管|文员|县长\
|乡长|校长|协理|药师|业主|园长|员工|院长|运营|站长|镇长|职工|法律部职员|职员|主编|主管|助理主任|\
主任|主席|专利代理人助理|助理|住持|专务|\
专员|总编|总裁|总监|组长|CE0|CEO|PaulBuysse长和AlbrechtDeGraeve董事\
|财务副董事长、首席财务官、财务主管兼秘书|公司法律顾问与商标及版权事务知识产权主管|\
副总裁、法律及知识产权事务助理总法律顾问|公司董事会助理秘书及公司助理首席法律顾问|\
法务部和事务部高级副总裁、法律顾问及秘书|助理秘书、高级副总裁兼首席知识产权顾问|\
董事长董事兼现金及衍生产品市场部负责人|副总法律兼交易和战略部首席知识产权顾问|\
授权代表、知识产权专利申请及诉讼部主管|副总裁、总法律顾问、首席法务官兼秘书|\
执行董事兼环球银行及资本市场业务主管|副总裁、总法律顾问、首席合规官兼秘书|\
副总裁、副总法律顾问兼助理董事会秘书|副总法律兼交易与策略首席知识产权顾问|\
第一副总裁、知识产权总顾问及助理秘书|法律顾问、商标及版权处知识产权负责人|\
董事会助理秘书及公司助理首席法律顾问|高级副总裁、首席法律顾问及董事会秘书|\
助理秘书、高级副总裁及知识产权总顾问|高级副总裁、首席法律顾问、董事会秘书|\
副总法律和交易与策略首席知识产权顾问|周吉宜兼以上十五位之共同委托代理人|副总裁、副总法律顾问兼公司助理秘书|\
执行副总裁兼首席行政官和总法律顾问|副总裁、副总法律顾问兼公司秘书助理|法务和企业联合部副总裁兼授权签字人|\
高级董事首席知识产权和诉讼法律顾问|事务高级副总裁、总法律顾问兼秘书|执行副总裁兼总法律顾问和公司秘书|\
财务副总裁兼首席财务官兼助理秘书|副总兼首席交易和战略知识产权顾问|董事兼现金及衍生产品市场部负责人|\
副总裁、助理总法律顾问兼助理秘书|高级副总裁、总法律顾问兼公司秘书|执行副总裁、总法律顾问兼公司秘书|\
高级副总裁、法务总监兼董事会秘书|高级副总裁兼集团总顾问、集团法务|董事会秘书及公司助理首席法律顾问|\
商标、法律及知识产权事务法律顾问|知识产权及标准部(中国区)负责人|首席财政官、财务主管及执行副总裁|\
首席财务官、运营副总裁及法律代表|首席法务官、法律总顾问及公司秘书|高级副总裁、法律总顾问及公司秘书|\
高级执行副总裁及知识产权管理经理|商业开发、法律及知识产权事务总监|董事会助理秘书及助理首席法律顾问|\
部门主任和公司名称或商标法律主管|法律企业、EMEA和APAC主管|助理公司秘书和知识产权助理总顾问|\
副总裁、副总法律顾问兼助理秘书|法律顾问兼全球商标实践组负责人|副总裁、助理法律顾问兼助理秘书|\
高级副总裁-法律顾问兼公司秘书|副总裁、副总法律顾问兼总裁助理|董事兼副社长执行董事兼财务总监|\
副总裁、副总法律顾问兼秘书助理|亚太、大中华及南非区首席执行官|副总裁、董事会秘书及总法律顾问|\
公司管理委员会及执行理事会主席|专利操作法律及知识产权事务总监|执行副总裁、法律总监及公司秘书|\
助理秘书及知识产权副总法律顾问|知识产权助理法律顾问及助理秘书|全球知识产权交易和战略高级顾问|\
职务资深法律顾问和知识产权主管|执行副总裁、商务法务和助理秘书|副总法律顾问兼法务审计部部长|\
高级副总裁、总法律顾问兼秘书|副总裁兼知识产权副总法律顾问|副总裁兼首席知识产权法律顾问|\
副总裁、总法律顾问兼公司秘书|高级副总裁-法律总顾问兼秘书|授权代表人兼商标事务法律顾问|\
会主席、首席执行官兼常务董事|财务和行政副总裁兼首席执行官|高级副总裁、法律总顾问兼秘书|\
副总裁(法律事务)兼公司秘书|高级副总裁、总顾问兼公司秘书|高级副总裁兼全球副总法律顾问|\
全球公司副总裁、总顾问兼秘书|财务副总裁、首席财务官兼主管|管理委员会董事长兼首席执行官|\
执行副总裁、总法律顾问兼秘书|董事执行官兼研究开发部总经理|执行副总裁兼总法律顾问及秘书|\
CRB‘‘LLC经理兼合伙人|上海古籍出版社副社长兼副总编|副总裁、法律总顾问兼公司秘书|高级副总裁及知识产权法律顾问|\
助理总法律顾问及首席商标律师|副总裁及知识产权副总法律顾问|副执行官、法律顾问及公司秘书|\
总理及原住民事务和糖业部部长|职务律师、知识产权部长及董事|高级副总裁、法律总顾问及秘书|\
职务副总法律顾问及执法副总裁|执行副总裁、总法律顾问及秘书|高级副总裁、总法律顾问及秘书|\
知识产权及标准部中国区负责人|执行副总裁和首席法务官及秘书|高级副总裁、总顾问及公司秘书|\
首席法律顾问助理和商标部主管|投票代理人和高级知识产权律师|公共事务和法律事务部执行总监|\
高级知识产权顾问和集群负责人|执行副总裁、公司总顾问和秘书|研究合作伙伴和技术转移部经理|\
副总裁、助理总顾问和助理秘书|副总裁、总法律顾问和公司秘书|助理总法律顾问和商标部门主管|\
总经理助理兼规划发展部部长|助理秘书兼全球反盗版副总裁|副本部长兼知识产权中心所长|高级副总裁、法务总监兼秘书|\
副总裁兼商标总法律顾问助理|秘书兼职业道德与合规副总裁|副总裁、副总顾问兼助理秘书|副总裁兼知识产权副法律顾问|\
助理秘书长兼商标与品牌总监|副总裁、总法律顾问兼总秘书|董事长、总经理兼首席执行官|顾问、高级副总裁兼公司秘书|\
运营执行副总裁兼法律总顾问|代表取缔役会长兼社长CEO|副总裁、法律顾问兼执行秘书|高级执行副总裁兼首席财务官|\
代表取缔役社长兼首席执行官|法律事务副总裁兼总法律顾问|职务集团董事长兼首席执行官|副总裁兼北美公司职能总顾问|\
北美地区董事长兼首席执行官|北美地区董事长兼首席运营官|高级副总裁兼全球总法律顾问|副总裁-法律兼公司助理秘书|\
行政副总裁、法律顾问兼秘书|副总兼首席知识产权法律顾问|执行副总裁、法律总监及秘书|专利、商标及许可证部总经理|\
第一副总裁及知识产权总顾问|财政、行政、采购及操作总监|金融、产品及区域高级副总裁|执行副总裁、总顾问及总秘书|\
专利法律及知识产权事务总监|高级副总裁、法律顾问及秘书|副总知识产权顾问及助理秘书|职务法律顾问及知识产权主管|\
副总法律顾问及知识产权总监|知识产权及诉讼副总法律顾问|专利及商标部门经理和代理人|总经理及广东保信事务所律师|\
公司法律董事及法定公司秘书|法律及公司事务部执行副总裁|公司和医疗事务部执行副总裁|高级财务副总监和首席财务官|\
资深法律顾问和知识产权主管|知识产权法副总裁和助理秘书|首席运营官和公司战略执行官|高级副总裁和首席法律执行官|\
副总裁兼首席知识产权顾问|副总裁兼总法律和税务顾问|助理秘书兼助理法律总顾问|执行副总裁、总顾问兼秘书|\
副总裁兼首席知识产权律师|法务执行副总裁兼公司秘书|执行董事兼质量保证部部长|秘书、总顾问兼高级副总裁|\
副总裁兼商业食品法律顾问|财务总监、秘书兼财务主管|副总裁、法律总顾问兼秘书|副总裁、总顾问兼公司秘书|\
高级副总裁、总顾问兼秘书|集团执行董事兼首席执行官|助理总法律顾问兼助理秘书|总经理(法务)兼公司秘书|\
董事会副主席兼首席执行官|党委书记、董事长兼总经理|高级执行总裁兼首席执行官|商标及版权顾问兼授权代表|\
法务副总裁兼首席专利顾问|高级副总裁兼首席法律顾问|副总裁兼知识产权法律顾问|副总裁兼副国际总法律顾问|\
助理秘书长兼副总法律顾问|知识产权全球总监兼代理人|合伙人兼美国区总法律顾问|高级副董事长兼总法务顾问|\
副总裁、首席财务官兼主管|董事该公司董事长兼总经理|总裁、首席执行官兼董事长|高级副总裁兼知识产权顾问|\
副总裁、助理总顾问兼秘书|执行(常务)董事兼总经理|大中华地区及亚太区代理人|集团财务及行政管理总经理|\
助理总法律顾问及助理秘书|集团首席法务官及公司秘书|律师、知识产权部长及董事|副总法律顾问及执行副总裁|\
商务及法律事务高级副总裁|高级副总裁及高级法律顾问|副总法律顾问及执法副总裁|顾问及全球商标运营组主管|\
技术管理和标准化部负责人|高级公司法律顾问和代理人|普通合伙人和独立法定代表|欧洲、中东和非洲运营经理|\
副总裁、总法律顾问和秘书|副总法律顾问和高级副总裁|知识产权律师和法定代理人|法律和公司事务高级副总裁|\
高级副总裁和公司法律顾问|品牌执行和商标法高级总监|董事长、首席执行官和主席|公司秘书和职业操守副总裁|\
副总裁、法律总顾问和秘书|总顾问和法律事务部负责人|战略发展顾问兼法律顾问|法定代表人兼实际经营者|\
委副书记兼办公室主任|副总工程师兼机械部主任|高级副总裁兼助理总顾问|法务副总裁兼总法律顾问|\
执行副总裁兼总法律顾问|高级副总裁兼首席财务官|职务高级副总裁兼总顾问|董事会主席兼首席执行官|\
董事局主席兼首席执行官|副总法律顾问兼助理秘书|共同创办人兼首席运营官|副总裁、秘书兼财务主管|\
集团首席执行官兼董事长|高级副总裁兼总法律顾问|助理法律顾问兼助理秘书|法律总顾问兼董事会秘书|\
助理秘书兼高级专利经理|高级副总裁兼法律总顾问|副总裁兼总法律顾问助理|执行副总裁兼首席财务官|\
副总裁、法律总监兼秘书|集团副总裁兼总法律顾问|副总裁兼法务及公司秘书|副总裁兼助理法律总顾问|\
副总裁兼助理总法律顾问|副总裁兼首席法律执行官|总法律顾问兼董事会秘书|资深法律顾问兼助理秘书|\
助理秘书兼高级法律顾问|高级副总裁兼公司总顾问|财务副总裁兼首席财务官|助理总顾问兼高级副总裁|\
营销总监兼授权高级职员|职务董事长兼首席执行官|公司行政总裁兼执行董事|秘书兼(美洲)法务顾问|\
执行副总裁兼首席运营官|高级副总裁兼董事会秘书|首席行政官兼总法律顾问|副总裁兼董事会常务主席|\
公司副总裁兼法律总顾问|公司副主席及助理总顾问|首席执行官及首席财务官|销售、市场及技术副总裁|\
法律顾问及知识产权律师|董事会主席及首席执行官|执行副总裁及法律总顾问|首席商标及版权顾问律师|\
法律董事及法定公司秘书|商标及知识产权部总顾问|副总裁及高级总法律顾问|高级副总裁及总法律顾问|\
董事总经理及法律总顾问|知识产权及许可部总经理|高级副总裁及法律总顾问|副总裁及知识产权总顾问|\
执行合伙人及总法律顾问|人力资源及法律部副总裁|法定代表人及实际经营者|副教授及原告法定代表人|\
董事会主席和首席执行官|总法律顾问和董事会秘书|专利、商标和许可总经理|首席执行官和董事会主席|\
知识产权部和商标部主任|欧洲、中东和非洲区主管|秘书和道德与守法副总裁|法律顾问和知识产权主管|\
副总裁、法律和助理秘书|高级副总裁和公司总顾问|高级法律顾问和商标经理|董事会董事和授权签字人|\
全球知识产权和执行总监|董事会成员和授权签字人|知识产权和打击仿冒经理|首席法律和知识产权总监|\
销售和营销副总裁、董事|公共关系部和财务部经理|高级副总裁和总法律顾问|商务和法务部高级副总裁|\
总经理助理兼法律顾问|高级副总裁兼公司秘书|副总裁兼助理法律顾问|副总裁兼副总法律顾问|常务董事兼首席执行官|\
高级副总裁兼副总顾问|总顾问、副总裁兼秘书|助理总法律顾问兼秘书|董事局主席兼集团总裁|副总裁兼首席专利顾问|\
副董事长兼首席执行官|执行副总裁兼法务总监|总法律顾问兼公司秘书|董事会主席兼行政总裁|公司秘书兼法定代表人|\
公司秘书兼高级副总裁|集团副总裁兼法律顾问|副总裁兼首席法律顾问|副总裁兼福总法律顾问|执行副总裁兼代表董事|\
助理秘书兼助理总顾问|副总裁、总顾问兼秘书|高级副总裁兼助理秘书|副总裁兼知识产权顾问|副总裁兼高级商标顾问|\
法律顾问兼董事会秘书|集团总顾问兼公司秘书|财务总监兼高级副总裁|董事局主席兼行政总裁|副总裁兼高级法律顾问|\
执行副总裁兼法律顾问|首席运营官兼公司秘书|副总裁兼法律顾问助理|、副总经理兼执行董事|执行副总裁兼财务主管|\
特别副总裁兼助理秘书|副总裁兼诉讼事务主管|副总裁兼副法律总顾问|法律顾问兼法务副总裁|高级副总裁兼法律顾问|\
邯郸县兼庄乡退休干部|助理总兼首席照明顾问|助理总顾问兼助理秘书|兼副总经理、执行董事|董事兼授权市场总经理|\
副会长兼任首席执行官|副总经理兼法律总顾问|副董事长兼总律师助理|系公司执行董事兼经理|副总裁兼助理公司秘书|\
副总裁兼秘书兼总顾问|职务执行董事兼总经理|副总裁及法律总监助理|商标及版权总法律顾问|知识产权及认证部经理|\
法务及知识产权部部长|助理总顾问及助理秘书|知识产权及法务部职员|法务及知识产权部主管|副董事长及首席执行官|\
法务及知识产权总经理|财务及成本控制部主管|商标、设计及域名主管|专利商标及许可总经理|集团首席法务官及秘书|\
知识产权及战略部部长|执行董事及总务部部长|副总裁及法律总裁助理|特许销售总经理及董事|副总裁及知识产权顾问|\
创新及企业关系部主任|商标、市场及广告总监|首席法务官及公司秘书|副总裁及副总法律顾问|高级副总裁及法务总监|\
许可及商业事务副总裁|集团总顾问及公司秘书|商务及法务高级副总裁|执行副总裁及财务总监|知识产权及认证部董事|\
总法律顾问及助理秘书|财务及行政执行副总裁|营销及商业部法律总监|职务许可及合同代理人|法律及公司事务部主管|\
法律及知识产权部主管|公司总顾问及公司秘书|销售及医务执行副总裁|管理董事及授权签字人|高级工程师及全权代表|\
市场营销及通讯部经理|高级副总裁及公司秘书|律师、商标及版权经理|技术中心及服务部董事|副总裁和副总法律顾问|\
首席运营官和公司秘书|抚顺市天和地板厂业主|副总裁、总顾问和秘书|涂料和精加工部副总裁|法务总监和总经理秘书|\
商务和法律事务副总裁|法律和商业事务副总裁|商标和知识产权总顾问|系佳和购物中心经营者|执行董事和高级副总裁|\
高级副总裁和法务总监|法律总顾问和公司秘书|高级副总裁和副总顾问|董事主席和首席执行官|集团首席法务官和秘书|\
商标和版权总法律顾问|知识产权和战略副总裁|法定代表人兼总经理|总裁助理兼法律顾问|副总经理兼技术总监|\
副董事长兼总工程师|总经理兼法定代表人|总经理兼党委副书记|副总裁兼授权签字人|副总裁兼总顾问助理|\
董事长兼首席执行官|总经理兼首席执行官|首席执行官兼董事长|副总裁兼首席执行官|总裁兼副总法律顾问|\
副总裁兼法律总顾问|副总裁兼总法律顾问|副总裁兼助理总顾问|法律顾问兼助理秘书|执行副总裁兼总顾问|\
副总裁兼副专利顾问|法务部主任兼代理人|副总裁兼首席财务官|助理部长兼法律顾问|董事总经理兼总顾问|\
高级副总裁兼总顾问|副总顾问兼助理秘书|公司副总裁兼总顾问|商标经理兼授权代表|董事会主席兼总经理|\
执行副总裁兼董事长|总经理兼总法律顾问|法定代表兼授权代表|副总裁兼副法律顾问|副会长兼首席执行官|\
高级副总裁兼总经理|首席财务官兼副总裁|助理秘书兼高级律师|代表兼常务执行董事|副总裁秘书兼总顾问|\
董事长兼首席运营官|总裁兼行政总执行官|助理顾问兼助理秘书|集团副总裁兼总顾问|助理秘书兼高级顾问|\
法律顾问兼公司秘书|法律顾问兼代理律师|副董事长兼财务总监|职务董事长兼总经理|重庆兼善事务所律师|\
职务执行董事兼经理|总编辑兼常务副社长|副总裁兼总经理秘书|法务主管兼公司秘书|驻以色列经理兼董事|\
副社长兼首席执行官|总经理兼首席财务官|系执行董事兼总经理|公司顾问兼公司秘书|职务董事长兼CEO|\
首席商标兼副总顾问|副主席兼首席执行官|总法律顾问兼副总裁|财务总监兼公司秘书|行政总裁兼执行董事|\
副总裁兼法定代表人|副总裁兼代理总顾问|副总裁兼总专利顾问|资深副总裁兼总顾问|执行董事兼任总经理|\
副总裁及首席执行官|首席商标及版权顾问|董事长及首席执行官|助理秘书及高级顾问|高级副总裁及总顾问|\
副总顾问及助理秘书|执行副总裁及总顾问|授权代表及财务总监|商标及版权事务总监|副总裁及首席运营官|\
知识产权及许可总监|执行董事及机要秘书|执行副及亚太区总裁|民事保护及诉讼总监|秘书部长及法务总监|\
法务及合规部副总裁|首席运营官及总顾问|董事总经理及总顾问|助理部长及高级顾问|财务总监及公司秘书|\
法律及公司事务经理|副总裁及总税务顾问|副总经理及财务主管|清算组成员及负责人|国际销售和服务经理|\
内部管理和审计经理|技术开发和保护经理|商标经理和助理秘书|销售和市场部副总裁|商标和产品法律顾问|\
商标和版权法律顾问|资深副总裁和总顾问|首席行政官和代理人|副总裁和总法律顾问|业务发展和执行董事|\
法律顾问和知产主管|首席执行官和董事长|知识产权部长和董事|法务和知识产权部长|集团顾问和法律顾问|\
广告和品牌管理顾问|财务总监和销售经理|执行副总和财务总监|商标和版权事务总监|董事会成员和代理人|\
实际控制人、总经理|法人代表兼总经理|会计兼办公室主任|董事长兼党委书记|总经理兼总工程师|董事长兼总工程师|\
销售部经理兼厂长|副总经理兼负责人|执行董事兼总经理|股东兼实际经营者|总法律顾问兼秘书|总裁兼首席执行官|\
主席兼首席执行官|董事兼总法律顾问|首席执行官兼总裁|高级副总裁兼秘书|秘书兼法律总顾问|副总裁兼助理秘书|\
副总裁兼审计主任|副总裁兼财务主管|会主席兼执行董事|执行副总裁兼秘书|总经理兼执行董事|副总裁兼法务主管|\
副总裁兼法律顾问|总裁兼首席运营官|副董事长兼总顾问|副总裁兼副总顾问|副总裁兼商标律师|副会长兼代表理事|\
法律总顾问兼秘书|总经理兼党委书记|董事长兼执行总裁|律师兼法律总顾问|董事兼首席执行官|秘书兼总法律顾问|\
总顾问兼公司秘书|副总裁兼专利律师|代表理事兼副会长|副总裁兼专利顾问|代理董事兼总经理|副总裁兼公司秘书|\
公司副总裁兼董事|公司董事兼总经理|法务副总裁兼秘书|代表董事兼总经理|社长兼首席执行官|秘书兼商务副总裁|\
副总裁兼秘书助理|副董事长兼总经理|秘书兼助理总顾问|副总裁兼法律总监|董事会成员兼秘书|副总裁兼首席顾问|\
总裁兼首席财务官|公司副总裁兼秘书|首席法律官兼秘书|集团总裁兼董事长|副主席兼首席顾问|职务董事兼总经理|\
副总裁兼法务总监|首席法务官兼秘书|法律部主任兼董事|副总裁兼商标顾问|秘书兼首席财务官|首席商标兼总顾问|\
高级副总裁兼总监|首席执行官兼董事|公司兼职工作人员|总裁兼董事会主席|首席财务官兼董事|首席财务官兼秘书|\
董事长兼研发总监|首席执行官兼社长|职务总经理兼董事|总裁及首席执行官|专利及商标代理人|执行副总裁及秘书|\
副总裁及法律顾问|总经理及授权代表|副总裁以及总顾问|副社长及代表董事|副总裁及助理秘书|总顾问及公司秘书|\
董事及授权签字人|首席执行官及董事|首席法务官及秘书|替任董事及副总裁|公司董事及总经理|执行董事及总经理|\
财务及运营负责人|销售及营销副总裁|专利代理人及律师|法定代表人及股东|专利代理人及职员|副总裁及法务总监|\
董事会主席及总裁|秘书及总法律顾问|副总裁及公司秘书|会主席及常务董事|秘书及首席财务长|总顾问和公司秘书|\
代理人和授权官员|主席和首席执行官|公司董事和总经理|商标和著作权总监|执行董事和总经理|总经理和法定代表|\
法律和税务部总监|董事和总法律顾问|首席执行官和总裁|精益眼镜店的员工|常务董事和代理人|董事和共同代理人|\
董事长兼总经理|执行董事兼经理|前台兼行政助理|股东兼副总经理|董事兼副总经理|法务兼信息专员|副总经理兼监事|\
副总裁兼总顾问|厂长兼技术总监|主席兼行政总裁|董事兼高级顾问|秘书兼财务主管|律师兼授权官员|总经理兼董事长|\
代理经理兼董事|董事兼助理秘书|董事长兼CEO|董事兼高级律师|董事兼执行秘书|合伙人兼总经理|副总裁兼总经理|\
法务兼商务总监|副社长兼总编辑|社长兼执行董事|CEO兼董事长|秘书兼法务总监|公司顾问兼秘书|法律顾问兼秘书|\
公司律师兼董事|顾问兼常务董事|代表董事兼总裁|秘书兼法律总监|主管兼助理秘书|董事兼财务经理|代表董事兼社长|\
董事长兼执行官|董事兼法务主管|财务主管兼秘书|经理兼执行董事|执行董事兼院长|总裁兼执行董事|所有人兼总经理|\
副长兼常务董事|唯一董事兼总裁|CE0兼董事长|党组书记兼局长|财务及行政主管|商标及版权主管|专利及许可部长|\
助理总法律顾问|公司顾问及秘书|市场及销售总监|副总裁及总经理|副总裁及总顾问|行政及财务总监|营销及服务总监|\
律师及律师助理|律师及实习律师|商标及版权经理|董事长及总经理|管理及销售经理|经理及公司秘书|总经理及副总裁|\
商标及外观顾问|资深顾问及律师|总经理及董事长|执行董事及经理|销售及市场经理|商标及设计法务|亿家酒店经营者|\
人事及财务主管|商标和外观主管|董事和授权代表|商标和版权顾问|财务和审计总监|工业和商务总监|行政和审计总监|\
代表董事和社长|副总裁和总经理|行政和财务总监|董事和法律顾问|商标和外观顾问|商标和版权经理|秘书和法务总监|\
董事和公司秘书|科学和运营总监|主席和执行总裁|执行总裁和董事|法律顾问和秘书|专利和商标专员|精益眼镜店员工|\
总经理和董事长|董事兼总经理|股东兼总经理|副总裁兼秘书|总经理兼董事|董事长兼厂长|董事长兼总裁|董事长兼社长|\
合伙人兼经理|长兼常务董事|总裁兼董事长|董事兼副总裁|长兼专务董事|社长兼总编辑|董事长兼校长|社长兼总经理|\
总顾问兼秘书|长兼代表董事|总裁兼CEO|副总裁兼董事|董事长兼经理|董事兼副主席|董事及总经理|董事长及总裁|\
董事及副总裁|总顾问及秘书|副总裁及秘书|个体户经营者|社长及总编辑|总经理及董事|律师及其助理|股东及负责人|\
销售部经营者|副主席和总裁|总裁和总经理|销售中心业主|信息中心主任|董事兼经理|个体工商户|兼法律顾问|股东兼员工|\
会长兼社长|董事兼秘书|董事兼总裁|主管兼秘书|总裁兼秘书|总裁兼董事|社长兼主编|社长兼总编|书记兼院长|及常务董事|\
董事及经理|董事及总裁|董事及秘书|主席及董事|个体经营者|法定代表人|律师及助理|主管工程师|总裁及董事|主管和董事|\
运营部经理|执行副总裁|总裁和秘书|总经理助理|仓库经营者|实际经营者|法制股股长|办公室主任|供销部长|商标评审员|\
助理总法律顾问|法务主管|法务副总裁|法务总监|法务经理|法务职员|法务董事|法务部长|\
法律事务部主管|法律事务部副总裁|法律事务部总监|法律事务部经理|法律事务部职员|法律事务部董事|法律事务部部长)$"



"""."""
import re
import time
import jieba


class Address(object):
    """docstring for Address."""

    def __init__(self):
        """."""
        self.gcountry = []
        self.gcountryAdd = []
        self.gcountryMap = dict()
        self.gprovince = ""
        self.gcity = ""
        self.gdistrict = ""
        self.gdistrictMap = dict()
        self.gcityMap1 = dict()
        self.gcityMap2 = dict()

    def get_address(
            self, id, business_address, address, registered_address):
        """."""
        country = ''
        province = ''
        city = ''
        district = ''
        detail = ''
        ctime = time.strftime('%Y-%m-%d %H:%M:%S')
        params = []
        if business_address:
            country, province, city, district, detail = self.parse_address(
                business_address)
            params.append((id, address, 3, country, province,
                           city, district, detail, ctime))
            # print('%s,%s,%s,%s' % (ctime, id, country, province))
        if address:
            country, province, city, district, detail = self.parse_address(
                address)
            params.append((id, address, 2, country, province,
                           city, district, detail, ctime))
            # print('%s,%s,%s,%s' % (ctime, id, country, province))
        if registered_address:
            country, province, city, district, detail = self.parse_address(
                registered_address)
            params.append((id, address, 1, country, province,
                           city, district, detail, ctime))
            # print('%s,%s,%s,%s' % (ctime, id, country, province))
        return country, params

    def parse_address(self, address):
        """
        地址解析.

        return:country,province,city,district,detail
        """
        country = ''
        province = ''
        city = ''
        district = ''
        detail = ''
        addCut = jieba.lcut(address)
        try:
            if addCut[0] in self.gcountry:
                country = self.gcountryMap.get(addCut[0])
            elif addCut[0] in self.gcountryAdd:
                country = addCut[0]
            if country:
                addCut.remove(addCut[0])

            if country and country != '中国':
                return (country, '', '', '', ''.join(addCut))

            # 解析省份，直辖市为特殊情况解析出市
            if not province:
                match = re.search(self.gprovince, addCut[0])
                if match:
                    country = '中国'
                    province = match.group(1)
                    if match.group(1) in ['北京', '天津', '上海', '重庆']:
                        city = match.group(1)
                    addCut.remove(addCut[0])
            if not city:
                match = re.search(self.gcity, addCut[0])
                if match:
                    city = match.group(1)
                    if not province:
                        id = self.gcityMap2.get(match.group(1))
                        province = self.gcityMap1.get(int(id / 10000) * 10000)
                        country = "中国"
                    addCut.remove(addCut[0])
            if city:
                match = re.search(self.gdistrict, addCut[0])
                if match:
                    district = match.group()
                    addCut.remove(addCut[0])
            elif province and not city and not district:
                match = re.findall(self.gdistrict, addCut[0])
                provinceNum = self.gcityMap2.get(province)
                if provinceNum:
                    provinceNum = int(provinceNum / 10000)
                    for m in match:
                        districtNum = self.gdistrictMap.get(m)
                        if provinceNum == int(districtNum / 10000):
                            district = m
                            city = self.gcityMap1.get(
                                int(districtNum / 100) * 100)
                            addCut.remove(addCut[0])
            detail = ''.join(addCut)
        except IndexError as e:
            print(e)
        return (country, province, city, district, detail)



# -*- coding: utf-8 -*-
"""
Created on Tue Aug  1 09:37:36 2017
@author: Administrator
"""
from .First_sub import MainCut1
from .Second_sub import MainCut2
from .Appealmoney1 import  MainLawsuit1
from .Jmoney1 import  Main_Judge1
import re
## 一审的诉讼请求,数据
###数据
def get_first_asuit(rawdata):
    x1=re.search("(诉讼请求|请求[^。]{,6}判令|请求判决[:： ]|诉称[:：]|诉讼请求为)[^\n]*",rawdata,re.S)
    if x1:
        x1=x1.group()
    else:
        x1=""
    return x1

## 最后判决结果
def Sub_Judge1(content):
        x=content.split("\n")
        st=""
        txt=""
        flag=False
        for j in x:
            txt+=j+"\n"
            x1=re.search("(判如下|判令如下|判决:|判决如下|综上,依据《中华人民共和|规定,如下:|(综上所述|综上).{,1}.*规定:)",j)
            fx=re.search("判决[^。，；]*(附图|附页):",j)
            ###
            if x1 and not fx:
                flag=True
                st=j+"\n"
            else:
                st+=j+"\n"
        x1=re.search("审判长|审判员|书记员|速录员|陪审员|速记员|法官助理",st)
        if x1:
            pre_txt=txt.replace(st,"")
        else:
            flag=False
            pre_txt=""
        ##需要存储于记录一下入库的错误类型
        return  pre_txt,st,flag
##shu
###一审判决结果
def get_firstjudge(rawdata):
    x1=re.search("(判决(如下|)[:：:]{1}|综上,依据《中华人民共和)[^\n]*",rawdata,re.S)
    if x1:
        subjudge=x1.group()
    else:
        subjudge=""
    return subjudge
def  Get_Appeal_Judge_Money(entity,rawdata):
    if entity.nature_=="刑事":
        pre_txt,st,flag=Sub_Judge1(rawdata)
        l=[(1,'3','3')]*11
        l[8]=(1,'3',st)
        entity.Judement=l[8][2]
        Jmoney=Main_Judge1(l)
        entity.judge_money=Jmoney
        return entity
    if entity.nature_!="民事":
        return entity
    if entity.level_=="一审":
        l=MainCut1((1,rawdata))
        if len(l)==11:
            money=MainLawsuit1(l)
            if money=="不祥":
                money="-1"
            entity.appeal_money=money
            Jmoney=Main_Judge1(l)
            if Jmoney=="不祥":
                Jmoney="-1"
            entity.judge_money=Jmoney
            entity.accuser=l[2][2]+l[3][2]
            entity.Judement=l[8][2]
        else:
            l=[(1,'2','')]*11
            asuit=get_first_asuit(rawdata)
            l[3]=(1,3,asuit)
            pre_txt,st,flag=Sub_Judge1(rawdata)
            if flag:
                judgcontent=st
                l[8]=(1,"2",judgcontent)
                Jmoney=Main_Judge1(l)
            else:
                Jmoney="不详"
            entity.judge_money=Jmoney
    elif entity.level_ =="二审":
        l,flag=MainCut2((1,rawdata))
        if len(l)==17:
            money=MainLawsuit2(l)
            Jmoney=Main_Judgment2(l)
            if Jmoney=="不详":
                Jmoney="-1"
            entity.judge_money=Jmoney
            entity.appeal_money=money
            entity.Judement=l[8][1]+l[14][1]
            entity.accuser=''
        else:
            l=[(1,'2','')]*17
            pre_txt,st,flag=Sub_Judge1(rawdata)
            first_judge=get_firstjudge(rawdata)
            if flag:
                judgcontent=st
                l[14]=(1,judgcontent,'8')
                l[8]=(1,first_judge,"")
                Jmoney=Main_Judge1(l)
            else:
                Jmoney="不详"
            entity.judge_money=Jmoney
    return entity



"""."""


class Person:
    """."""

    def __init__(self):
        """."""
        self.name_ = ""  # 姓名
        self.usedname_ = ""  # 曾用名
        self.role_ = ""  # 身份
        self.roleid_ = ""  # 1.原告 2.被告 3.第三人
        self.identity_ = ""  # 身份 1.当事人 2.法定代表人 3.诉讼代表人 4.授权代表人 5.其它
        self.firrole_ = ""  # 一审身份
        self.secrole_ = ""  # 二审身份
        self.nation_ = ""  # 民族
        self.sex_ = ""  # 性别
        self.birth_ = ""  # 出生日期
        self.b_year_ = ""
        self.b_month_ = ""
        self.b_day_ = ""
        self.address_ = ""  # 住所地址
        self.registered_address_ = ""  # 注册地址
        self.business_address_ = ""  # 经营地址
        self.country_ = ""  # 国籍
        self.company_ = ""  # 公司
        self.title_ = ""  # 职务
        self.other_ = ""  # 其它
        self.common_ = ''  # 共同代理人（1-10|共同）

    def __repr__(self):
        """."""
        return '%s,%s,%s' % (self.role_, self.name_, self.birth_)

    def to_csv(self):
        """."""
        tmp = [
                "name=%s" % self.name_, "sexy=%s" % self.sex_,
                "birth=%s" % self.birth_, "address=%s" %
                self.address_, "country=%s" % self.country_,
                "company=%s" % self.company_, "job_title=%s" % self.title_]
        return ",".join(tmp)

    def to_list(self):
        """."""
        member_list = [self.name_, self.sex_, self.birth_,
                       self.address_, self.country_,
                       self.company_, self.title_]
        return member_list


class RelativePerson:
    """."""

    def __init__(self):
        """."""
        self.person_ = Person()
        self.proxy_ = []
        self.legal_representative_ = []
        self.relative_ = []  # 新版，代理人和法人放在一起
        self.previous_id_ = ""

    def __repr__(self):
        """."""
        return '<当事人 % r>' % self.person_.name_ + '\n' \
            '<代理人 % r>' % self.proxy_ + '\n' \
            '<法人代表 % r>' % self.legal_representative_

    def to_csv(self):
        """."""
        tmp = [self.person_.name_, self.person_.address_,
               self.person_.country_]  # 当事人个人信息，名字，地址，国籍
        for p in self.legal_representative_:
            tmp.append(p.name_)
        for p in self.proxy_:
            tmp.append(p.name_)
            tmp.append(p.company_)
            tmp.append(p.title_)
        return "-".join(tmp)


class LawEntity:
    """."""

    def __init__(self):
        """."""
        self.id_ = "-1"
        self.title_ = ''  # 文书标题
        self.court_ = ""  # 审理法院
        self.court_level_ = ""  # 法院级别
        self.area_ = ""  # 案件地区
        self.is_foreign_ = False
        self.year_to_accept_ = None  # 立案年度
        self.type_ = ""  # 文书类型
        self.nature_ = ""  # 案件性质
        self.number_ = ""  # 案件号
        self.start_time_ = ""  # 案件开始时间
        self.level_ = ""  # 诉讼等级
        self.parent_ = ""  # 上一级诉讼号
        self.judge_time_ = ""  # 判决时间
        self.judge_results_ = []  # 判决结果
        self.reception_time_ = ''  # 受理时间
        self.court_time_ = ''  # 开庭时间
        self.trademark_id_ = ""  # 商标号
        self.patent_id_ = ""  # 专利号
        self.yuangao_ = []  # 原告
        self.beigao_ = []  # 被告
        self.third_people_ = []  # 第三人
        self.party_ = []  # 新版，集合原告，被告和第三人
        self.presiding_judge_ = []  # 审判长
        self.judges_ = []  # 审判员
        self.juror_ = []  # 陪审员
        self.clerk_ = []  # 书记员
        self.judge_assistant_ = []  # 法官助理
        self.pre_judge_ = []
        self.pre_law_type_ = []
        self.next_judge_ = []
        self.cause_ = ""  # 案由
        self.law_ = set()  # 法条
        self.patent_number_ = set()  # 专利号
        self.review_ = set()  # 专利复审
        self.trademark_number_ = set()  # 商标号
        self.trademark_review_ = set()  # 商标评审
        self.appeal_money_ = ''
        self.judge_money_ = ''
        self.accuser_ = ''
        self.Judement_ = ''

    def __repr__(self):
        """."""
        yuangao = []
        yuangao_rep = []
        yuangao_proxy = []
        for yg in self.yuangao_:
            yuangao.append(yg.person_.name_)
            for rep in yg.legal_representative_:
                yuangao_rep.append(rep.name_)
            for proxy in yg.proxy_:
                yuangao_proxy.append(proxy.name_)
        beigao = []
        beigao_rep = []
        beigao_proxy = []
        for bg in self.beigao_:
            beigao.append(bg.person_.name_)
            for rep in bg.legal_representative_:
                beigao_rep.append(rep.name_)
            for proxy in bg.proxy_:
                beigao_proxy.append(proxy.name_)
        third_people = []
        third_people_rep = []
        third_people_proxy = []
        for tp in self.third_people_:
            third_people.append(tp.person_.name_)
            for rep in tp.legal_representative_:
                third_people_rep.append(rep.name_)
            for proxy in tp.proxy_:
                third_people_proxy.append(proxy.name_)
        presiding_judge = []
        for pj in self.presiding_judge_:
            presiding_judge.append(pj.name_)
        judges = []
        for jud in self.judges_:
            judges.append(jud.name_)
        juror = []
        for jur in self.juror_:
            juror.append(jur.name_)
        clerk = []
        for cle in self.clerk_:
            juror.append(cle.name_)
        judge_assistant = []
        for ja in self.judge_assistant_:
            judge_assistant.append(ja.name_)
        return '<文书标题 % r>' % self.title_ + '\n' \
            '<审理法院 % r>' % self.court_ + '\n' \
            '<法院级别 % r>' % self.court_level_ + '\n' \
            '<案件地区 % r>' % self.area_ + '\n' \
            '<是否涉外 % r>' % self.is_foreign_ + '\n' \
            '<立案年度 % r>' % self.year_to_accept_ + '\n' \
            '<文书类型 % r>' % self.type_ + '\n' \
            '<案件性质 % r>' % self.nature_ + '\n' \
            '<案件号 % r>' % self.number_ + '\n' \
            '<案件开始时间 % r>' % self.start_time_ + '\n' \
            '<诉讼等级 % r>' % self.level_ + '\n' \
            '<上一级诉讼号 % r>' % self.parent_ + '\n' \
            '<判决时间 % r>' % self.judge_time_ + '\n' \
            '<判决结果 % r>' % self.judge_results_ + '\n' \
            '<受理时间 % r>' % self.reception_time_ + '\n' \
            '<开庭时间 % r>' % self.court_time_ + '\n' \
            '<商标号: % r>' % self.trademark_id_ + '\n' \
            '<专利号 % r>' % self.patent_id_ + '\n' \
            '<审判长 % r>' % presiding_judge + '\n' \
            '<审判员 % r>' % judges + '\n' \
            '<陪审员 % r>' % juror + '\n' \
            '<书记员 % r>' % clerk + '\n' \
            '<法官助理 % r>' % judge_assistant + '\n' \
            '<案由 %r>' % self.cause_ + '\n' \
            '<前一级案号 %r>' % self.pre_judge_ + '\n' \
            '<前一级类型 %r>' % self.pre_law_type_ + '\n' \
            '<法条 %r>' % self.law_ + '\n' \
            '<专利号 %r>' % self.patent_number_ + '\n' \
            '<专利复审文书号 %r>' % self.review_ + '\n' \
            '<商标号 %r>' % self.trademark_number_ + '\n' \
            '<商标评审文书号 %r>' % self.trademark_review_

    def to_csv(self):
        """."""
        tmp = []
        tmp.append(self.id_)  # 文书id 0
        tmp.append(self.number_)  # 案件号 1
        tmp.append(self.court_)  # 法院名称 2
        tmp.append(self.court_level_)  # 法院级别3
        tmp.append(self.area_)  # 案件地区4
        tmp.append(self.nature_)  # 案件性质5， 行政、民事
        tmp.append(self.type_)  # 文书类型6，	判决书、调解书
        tmp.append(self.year_to_accept_)  # 案件时间7

        tmp.append(self.level_)  # 诉讼等级8
        tmp.append("1" if self.is_foreign_ else "0")  # 是否涉外9
        tmp.append("#".join(self.to_db(self.yuangao_)))  # 原告10-16
        tmp.append("#".join(self.to_db(self.beigao_)))  # 被告17-23
        tmp.append("#".join(self.to_db(self.third_people_)))  # 第三人24-30

        faguans = [p.name_ for p in self.presiding_judge_]  # 审判长31
        shenpanyuan = [p.name_ for p in self.judges_]  # 审判员32
        peishenyuan = [p.name_ for p in self.juror_]  # 陪审员33
        shujiyuan = [p.name_ for p in self.clerk_]  # 书记员34
        faguanzhuli = [p.name_ for p in self.judge_assistant_]  # 法官助理35
        tmp.append(",".join(faguans))
        tmp.append(",".join(shenpanyuan))
        tmp.append(",".join(peishenyuan))
        tmp.append(",".join(shujiyuan))
        tmp.append(",".join(faguanzhuli))
        # tmp.append(self.trademark_id_)											#商标号36
        # tmp.append(self.patent_id_)												#专利号37
        judge_result = "" if len(self.judge_results_) == 0\
            else self.judge_results_[
            len(self.judge_results_) - 1]
        tmp.append(judge_result)  # 判决结果38
        yishenanhao = ""
        ershenanhao = ""
        sanshenanhao = ""
        yishenjieguo = ""
        ershenjieguo = ""
        sanshenjieguo = ""
        if self.level_ == "二审":
            ershenanhao = self.number_
            ershenjieguo = judge_result
            yishenjieguo = "" if len(self.judge_results_) < 2 else "~".join(
                self.judge_results_[:-1])
            yishenanhao = "" if len(
                self.pre_judge_) == 0 else self.pre_judge_[0]
        elif self.level_ == "一审":
            yishenanhao = self.number_
            yishenjieguo = judge_result
        elif self.level_ == "三审":
            sanshenanhao = self.number_
            yishenanhao = "" if len(
                self.pre_judge_) != 2 else self.pre_judge_[0]
            ershenanhao = "" if len(self.pre_judge_) == 0 else self.pre_judge_[
                len(self.pre_judge_) - 1]
            sanshenjieguo = judge_result
            ershenjieguo = "" if len(
                self.judge_results_) < 2 else self.judge_results_[-2]
            yishenjieguo = "" if len(self.judge_results_) < 3 else "~".join(
                self.judge_results_[:-1])
        tmp.append(yishenanhao)  # 一审案号39
        tmp.append(ershenanhao)  # 二审审案号40
        tmp.append(self.judge_time_)
        tmp.append(sanshenanhao)  # 三审审案号40
        tmp.append(yishenjieguo)  # 一审结果
        tmp.append(ershenjieguo)  # 二审结果
        tmp.append(sanshenjieguo)  # 三审结果
        caijueshuhao = ""
        if self.trademark_id_ != "":
            caijueshuhao = self.trademark_id_
        elif self.patent_id_ != "":
            caijueshuhao = self.patent_id_
        tmp.append(caijueshuhao)
        return "#".join(tmp)

    def to_db(self, parties):
        """."""
        names = []
        address = []
        countries = []
        proxies_name = []
        proxies_company = []
        proxies_title = []
        legal_representatives = []
        for party in parties:
            names.append(party.person_.name_)
            address.append(party.person_.address_)
            countries.append(party.person_.country_)
            for p in party.legal_representative_:
                legal_representatives.append(p.name_)
            if len(party.legal_representative_) == 0:
                legal_representatives.append("")
            if len(party.proxy_) == 0:
                p = Person()
                party.proxy_.append(p)
            for p in party.proxy_:
                proxies_name.append(p.name_)
                proxies_company.append(p.company_)
                proxies_title.append(p.title_)
        return [
            self.to_combination_str(names), self.to_combination_str(address),
            self.to_combination_str(countries),
            self.to_combination_str(legal_representatives),
            self.to_combination_str(proxies_name),
            self.to_combination_str(proxies_company),
            self.to_combination_str(proxies_title)]

    def to_combination_str(self, data_list):
        """."""
        return ",".join(data_list)

    def to_json(self):
        """."""
        yuangao = [p.to_csv() for p in self.yuangao_]
        beigao = [p.to_csv() for p in self.beigao_]
        third_people = [p.to_csv() for p in self.third_people_]
        tmp = "审理法院 : %s\n" % self.court_
        tmp += "法院级别 : %s\n" % self.court_level_
        tmp += "是否涉外 : %s\n" % ("是" if self.is_foreign_ else "否")
        tmp += "案件号 : %s\n" % self.number_
        tmp += "立案年度 : %s\n" % self.year_to_accept_
        tmp += "案件地区 : %s\n" % self.area_
        tmp += "案件性质 : %s\n" % self.nature_
        tmp += "文书类型 : %s\n" % self.type_
        tmp += "案件开始时间 : %s\n" % self.start_time_
        tmp += "诉讼等级 : %s\n" % self.level_
        tmp += "上一级诉讼号 : %s\n" % (",".join(self.pre_judge_))
        tmp += "判决时间 : %s\n" % self.judge_time_
        tmp += "裁决结果 : %s\n" % self.judge_result_
        tmp += "原告 : %s\n" % "~".join(yuangao)
        tmp += "被告 : %s\n" % "~".join(beigao)
        tmp += "第三人 : %s\n" % "~".join(third_people)
        tmp += "审判长 : %s\n" % "~".join([judge.to_csv()
                                        for judge in self.presiding_judge_])
        tmp += "审判员 : %s\n" % "~".join([judge.to_csv()
                                        for judge in self.judges_])
        tmp += "陪审员 : %s\n" % "~".join([judge.to_csv()
                                        for judge in self.juror_])
        tmp += "书记员 : %s\n" % "~".join([judge.to_csv()
                                        for judge in self.clerk_])
        tmp += "法官助理 : %s\n" % self.judge_assistant_.to_csv()
        tmp += "审理时间 : %s\n" % self.judge_time_
        return tmp



"""案由."""
import pymysql
import re
import os
import sys


def getTxt(path):
    """民事案由标准化文件."""
    txt = open(path)
    cList = []
    for line in txt:
        cArray = line.split("——>")
        cTuple = (cArray[0].strip(), cArray[1].strip())
        cList.append(cTuple)
    return cList


def truncate(content):
    """
    民事文书.

    对原始文书截断
    （一案|二案|三案|四案|五案|六案|七案|八案|九案|十案|纠纷）从前到后优先级查找
    去掉之前的中文字符集【】,[],（）,(),《》,“”,"",'‘,’'之间的内容
    截取一案之前的整句
    """
    keywords = ['一案', '二案', '三案', '四案', '五案', '六案', '七案', '八案', '九案', '十案',
                '系列案', '两案', '为由', '纠纷']
    m = None
    match = re.search('案由[:：](.*)', content)
    if match:
        return match.group(1).strip()
    for key in keywords:
        m = re.search(r'(.*?)%s' % key, content)
        if m is not None:
            break
    if m is None:
        return ''
    subStr = m.group(1)
    if key == '纠纷':
        subStr = subStr + '纠纷'
    subStr = re.sub(
        r'(\[.*?\]|【.*?】|\(.*?\)|（.*?）|《.*?》|".*?"|“.*?”|\'.*?\'|‘.*?’)',
        '', subStr)
    array = subStr.split("。")
    return array[len(array) - 1].strip()


def clean(coastr, results):
    """."""
    for par in results:
        if par:
            par = par.replace('(', '\(')
            par = par.replace(')', '\)')
            par = par.replace('*', '\*')
            par = par.replace('+', '\+')
            par = par.replace('[', '\[')
            par = par.replace(']', '\]')
            try:
                coastr = re.sub('.*%s' % par, '', coastr)
            except Exception as e:
                print('par:%s,coastr:%s' % (par, coastr))
                raise
    return coastr


def standardized(cause):
    """
    民事文书.

    标准化
    t_add_case_anyou表,anyou2字段是经过清洗后的字段，使用该字段匹配关键词确定案由
    return:['案由1','案由2'...]
    """
    ABSPATH = os.path.dirname(os.path.abspath(sys.argv[0]))
    regList = getTxt(ABSPATH + "/config/cause_standardization.txt")
    returnList = []
    if cause is None or cause == '':
        return returnList
    arr = []
    if re.search('著作权(权属)?(、|和|及)(权属)?侵权(纠纷)?', cause):
        arr.append(cause)
    else:
        arr = re.split('、|和|及', cause)
    for sa in arr:
        anyou = None
        for regTuple in regList:
            reg = regTuple[0]
            match = re.search(r'%s' % reg, sa)
            if match is not None:
                anyou = regTuple[1]
                break
        if anyou is not None:
            returnList.append(anyou)
    if len(returnList) <= 1:
        return ''.join(returnList)
    return returnList


def truncate_administrative(line):
    """行政文书 案由截断."""
    key = ['纠纷', '一案', '向本院提起', '向本院提出', '向本院申请', '审理终结', '审查终结', '提起行政诉讼']
    locate = ['商标([\u4e00-\u9fa5]+)行政', '商标([\u4e00-\u9fa5]+)裁定',
              '商标([\u4e00-\u9fa5]+)决定', '专利权?([\u4e00-\u9fa5]+)行政',
              '专利权?([\u4e00-\u9fa5]+)裁定',
              '专利权?([\u4e00-\u9fa5]+)决定']
    if not line:
        return ''
    for k in key:
        index = line.find(k)
        if index != -1:
            cause = line[:index + len(k)]
            cause = cause.strip()
            for l in locate:
                match = re.search(l, cause)
                if match:
                    return match.group(1)
            return cause
    return ''


reg_administrative = {'驳回': '驳回复审', '无效': '无效宣告', '异议': '异议复审', '争议': '争议',
                      '撤销复审': '撤销复审',
                      '专利(权)?(申请)?(复审)?(行政)?(确权)?(纠纷|诉讼)': '其他专利行政授权确权纠纷',
                      '(其他|因)?商标(行政)?纠纷': '其他商标行政授权确权纠纷',
                      '商标.*转让(申请)?': '其他商标行政授权确权纠纷',
                      '行政处罚': '行政处罚', '商标.*核准转让': '其他商标授权确权纠纷',
                      '商标申请不予核准': '不予注册复审',
                      '商标撤销行政纠纷': '撤销复审', '商标不予注册复审行政纠纷': '不予注册复审'}


def standardized_administrative(cause):
    """行政文书 案由标准化."""
    if not cause:
        return ''
    for r in reg_administrative:
        if re.search(r, cause):
            return reg_administrative.get(r)
    return ''


def truncate_crime(line):
    """刑事文书,案由截断."""
    reg = '.*(一案|审查终结|审理终结|审理完毕|组成合议庭|本院受理后|向本院提起公诉)'
    match = re.search(reg, line)
    if match:
        return match.group()
    return ''


def standardized_crime(cause):
    """刑事文书,案由标准化."""
    ABSPATH = os.path.dirname(os.path.abspath(sys.argv[0]))
    regList = getTxt(ABSPATH + "/config/cause_crime_standardization.txt")
    for regTuple in regList:
        reg = regTuple[0]
        match = re.search(r'%s' % reg, cause)
        if match is not None:
            return regTuple[1]
    return ''


def truncate_main(nature, line):
    """."""
    cause = ''
    if nature == '民事' or nature == '行政':
        cause = truncate(line)
    # if nature == '行政':
    #     cause = truncate_administrative(line)
    if nature == '刑事':
        cause = truncate_crime(line)
    return cause


def standardized_main(nature, cause):
    """."""
    anyou = ''
    if nature == '民事':
        anyou = standardized(cause)
    if nature == '行政':
        anyou = standardized_administrative(cause)
    if nature == '刑事':
        anyou = standardized_crime(cause)
    return anyou


def administrative_cause():
    """行政案件，根据当事人区分商标和专利的无效宣告、驳回复审区分，需要整合进案由标准化的代码."""
    sql = '''SELECT id, caseid, anyou from ip_infos.t_case_coa_relations
        where id>%s and (anyou = '无效宣告' or anyou = '驳回复审')
        order by id limit 1000'''
    sqlParties = '''SELECT name from ip_infos.t_case_parties
        where identity = 1 and caseid = %s'''
    sqlUpdate = '''UPDATE ip_infos.t_case_coa_relations set anyou = %s
        where id = %s'''
    conn = pymysql.connect(host="rm-2ze0ek7c57w65y4t6o.mysql.rds.aliyuncs.com",
                           user="ip_infos_root", passwd="zcb!1511",
                           charset="utf8")
    cur = conn.cursor()
    pageNum = 0
    while True:
        print(pageNum)
        cur.execute(sql, pageNum)
        results = cur.fetchall()
        if len(results) == 0:
            break
        for record in results:
            id = record[0]
            pageNum = id
            caseid = record[1]
            anyou = record[2]
            cur.execute(sqlParties, caseid)
            print(id)
            for r in cur.fetchall():
                if re.search('专利局|国家知识产权局|知识产权局|专利评审委员会|专利复审委员会', r[0]):
                    cur.execute(sqlUpdate, (anyou + "(专利)", id))
                    print('%s,%s' % (caseid, anyou + "(专利)"))
                    break
                elif re.search('商标局|商标复审委员会|商标评审委员会', r[0]):
                    cur.execute(sqlUpdate, (anyou + "(商标)", id))
                    print('%s,%s' % (caseid, anyou + "(商标)"))
                    break
        conn.commit()


if __name__ == '__main__':
    administrative_cause()



"""工具."""
from .main_conf import PUNCTUATION, PUNCTUATION_ALL, NUMBERS, YISHEN_MIN_PAN,\
    ERSHEN_MIN_PAN, YISHEN_MIN_CAI, ERSHEN_XING_PAN, ERSHEN_CAI
import jieba
from jieba import posseg
import codecs
from .dicts import NationalDict, AddressDict
import re

# ABSPATH = os.path.abspath(__file__)
# ABSPATH = os.path.dirname(ABSPATH)+"/"
# 民族
nationalDict = NationalDict("national", "config/national.txt")
# 国家
countryDict = NationalDict("country", "config/country.txt")
# 人民法院
primaryCourtDict = NationalDict("primaryCourt", "config/primary_courts.txt")
# 中级人民法院
middleCourtDict = NationalDict("middleCourt", "config/middle_courts.txt")
# 高级人民法院
advancedCourtDict = NationalDict("advancedCourt", "config/advanced_courts.txt")
# 住所地描述关键词
addressKeyWordDict = NationalDict(
    "address_key_word", "config/address_key_word.txt")
# 省市
cityToProvinceDict = AddressDict("city_province", "config/city_province.txt")
# 省县
townToProvinceDict = AddressDict("town_province", "config/town_province.txt")


def load_dict():
    """载入字典，载入各种各样的字典."""
    DICT = dict()
    DICT["national"] = nationalDict
    DICT["country"] = countryDict
    DICT["primary_court"] = primaryCourtDict
    DICT["middle_court"] = middleCourtDict
    DICT["advanced_court"] = advancedCourtDict
    DICT["address_key_word"] = addressKeyWordDict
    DICT["city_province"] = cityToProvinceDict
    DICT["town_province"] = townToProvinceDict
    for dict_name, dic in DICT.items():
        dic.load_dict()


def seg_words(text):
    """
    分词, 并去掉最后一个标点.

    input : 文本字符串
    output : 词列表
    """
    words = jieba.cut(text, cut_all=False)
    words = [w for w in words]
    index = len(words) - 1
    while index >= 0:
        if words[index] in PUNCTUATION:
            index -= 1
        else:
            break
    words = words[:index + 1]
    return words


def seg_words_with_pos(text):
    """
    带标注分词.

    input : 文本字符串
    output : 词列表
    """
    words = posseg.cut(text)
    words = [w for w in words]
    index = len(words) - 1
    while index >= 0:
        if words[index].word in PUNCTUATION:
            index -= 1
        else:
            break
    words = words[:index + 1]
    return words


def get_next_line(file_path):
    """
    从本地文件获取文本内容的生成器.

    EOF 表示完结
    """
    with codecs.open(file_path, "r", 'GBK') as f:
        while True:
            try:
                line = f.readline()
            except UnicodeDecodeError:
                f = codecs.open(file_path, "r", 'UTF-8')
                line = f.readline()
            if not line:
                yield 'EOF', ""
                break
            raw_line = line
            # line = line.strip()
            line = pre_process(line)
            if not line:
                continue
            yield line, raw_line
            global LINE_COUNT
            LINE_COUNT += 1


def get_next_line2(raw):
    """
    从数据库获得原始文本，生成器.

    EOF 表示完结
    """
    for line in raw.split('\n'):
        if line.strip() == '':
            continue
        raw_line = line
        line = pre_process(line)
        yield line, raw_line
    yield 'EOF', ""


def pre_process(line):
    """
    文本字符串预处理.

    去除空格
    去除全角符号
    """
    line = re.sub(r"[ \u3000\t\s]*", "", line)  # \u3000 审判长\u3000某某
    return line


def startWith(key_words, line):
    """If a line contains one of the word in key_words."""
    tokens = segmentSentence(line)
    if len(tokens) == 0:
        return ''
    for word in key_words:
        if tokens[0].startswith(word):
            return word
    return ''


def segmentSentence(line):
    """."""
    # print "分之前 : ", line
    result = []
    tmp = ""
    flag = 0
    for c in line:
        if c not in PUNCTUATION_ALL or flag == 1:
            if c in ['(', '（']:
                flag = 1
            if c in [')', '）']:
                flag = 0
            tmp += str(c)
        else:
            result.append(tmp)
            tmp = ""
    if len(tmp) > 0:
        result.append(tmp)
    return result


def contains(key_words, line):
    """If a line contains one of the word in key_words."""
    for word in key_words:
        if word in line:
            return True
    return False


def fixname(person):
    """."""
    name = person.name_
    name = re.sub('\(以下简称[^\)]*?\)', '', name)
    name = re.sub('\(组织机构代码[^\)]*?\)', '', name)
    name = re.sub('\(下称[^\)]*?\)', '', name)
    name = re.sub('\(统一社会信用代码[^\)]*?\)', '', name)
    name = re.sub('\(反诉[^\)]*?\)', '', name)
    name = re.sub('[\[\(]原名[^\)]*?[\)\]]', '', name)
    name = re.sub('\(系[^\)]*?经营者\)', '', name)
    name = re.sub('\(系[^\)]*?业主\)', '', name)
    person.name_ = name


def start_with_number(test):
    """."""
    for c in test:
        if c in NUMBERS:
            return True
        return False


def is_address(text):
    """判断一个字符串是否是地址串."""
    text = text.strip()
    if not text:
        return False
    segment_words = posseg.cut(text)
    words = [w for w in segment_words]
    for word in words:
        if word.flag == "ns":
            return True
        else:
            return False
    return False


def add_labels(raw_txt, labels):
    """
    给识别出来的标签增加表示，利于在UI上展示.

    比如标签“法院名称”，会被拓展成：<span id="court">北京市人民法院</span>
    """
    if len(labels) == 0:
        return raw_txt
    label_format = "<span class=\"%s\">%s</span>" % (" ".join(labels), raw_txt)
    return label_format


def rexMatch(pattern, str):
    """正则."""
    p = re.compile(pattern)
    m = p.search(str)
    if m:
        return m
    return []


def rexMatchAll(pattern, str, index):
    """."""
    p = re.compile(pattern)
    m = p.findall(str)
    if m:
        return m[0][index]
    return ""


def rexMatchAll3(pattern, str):
    """."""
    p = re.compile(pattern)
    m = p.findall(str)
    if m:
        for match in m:
            tmp = list(match)
            return "".join(tmp)
    return ""


def rexMatchAll2(pattern, str):
    """."""
    p = re.compile(pattern)
    m = p.findall(str)
    if m:
        result = []
        for match in m:
            tmp = list(match)
            result.append("".join(tmp))
        return result
    return []


def rexMatchAllYiShenAnHao(pattern, str):
    """."""
    p = re.compile(pattern)
    m = p.findall(str)
    if m:
        result = []
        types = []
        for match in m:
            tmp = list(match)
            types.append(tmp[-2:])
            tmp = tmp[0:-2]
            result.append("".join(tmp))
        return result, types
    return [], []


def format_yishen_panjue(case_type, law_type, judge_result):
    """."""
    result = judge_result
    # print '一审结果 : %s' % judge_result
    if case_type == "民事" and "判决" in law_type:
        result = "(部分)支持原告诉讼请求)"
        match = rexMatch(YISHEN_MIN_PAN[0], judge_result)
        if match:
            result = YISHEN_MIN_PAN[1]
    elif case_type == "行政" and "判决" in law_type:
        if "维持" in judge_result:
            result = "维持行政裁决"
        elif "驳回" in judge_result:
            result = "驳回原告诉讼请求"
        elif "撤销" in judge_result:
            result = "撤销行政裁决"
    elif "裁定" in law_type:
        if "移送" in judge_result:
            result = "移送审理"
        elif "终结诉讼" in judge_result:
            result = "终结诉讼"
        elif "转为普通程序" in judge_result:
            result = "转为普通程序"
        else:
            for pattern in YISHEN_MIN_CAI:
                match = rexMatch(pattern[0], judge_result)
                if match:
                    result = pattern[1]
                    break
    return result


def format_ershen_panjue(case_type, law_type, judge_result):
    """."""
    # print '二审结果 : %s' % judge_result
    result = judge_result
    if case_type == "民事" and "判决" in law_type:
        result = "部分维持、部分撤销一审判决"
        for pattern in ERSHEN_MIN_PAN:
            match = rexMatch(pattern[0], judge_result)
            if match:
                result = pattern[1]
                break
    elif case_type == "行政" and "判决" in law_type:
        result = "撤销一审判决"
        for pattern in ERSHEN_XING_PAN:
            match = rexMatch(pattern[0], judge_result)
            if match:
                result = pattern[1]
                break
    elif "裁定" in law_type:
        if "移送" in judge_result:
            result = "移送审理"
        elif "终结诉讼" in judge_result:
            result = "终结诉讼"
        elif "中止诉讼" in judge_result:
            result = "中止诉讼"
        else:
            for pattern in ERSHEN_CAI:
                match = rexMatch(pattern[0], judge_result)
                if match:
                    result = pattern[1]
                    break
    return result


def clean(file_path):
    """文书清理."""
    print('清洗文书:%s' % file_path)
    rawdata = ''
    # with codecs.open(file_path, "r", 'GBK') as f:
    with open(file_path, "r", encoding='GBK') as f:
        try:
            rawdata = f.read()
        except UnicodeDecodeError:
            # f = codecs.open(file_path, "r", 'UTF-8')
            try:
                f = open(file_path, "r")
                rawdata = f.read()
            except UnicodeDecodeError:
                f = open(file_path, "r", encoding='UTF-16')
                rawdata = f.read()
    rawdata = rawdata.strip()
    if rawdata.startswith('<meta'):
        raise Exception("文件格式错误，<meta 开头")

    # 清理北知文书中判决摘要的情况
    rawdata = re.sub('北京知识产权法院(.|\n)*本摘要并非判决之组成部分，不具有法律效力。', '', rawdata)

    rawdata = re.sub(r"[ \u3000\t]*", "", rawdata)
    match = re.findall('书记员.*', rawdata)
    if len(match) > 0:
        rawdata = rawdata[:rawdata.rfind(match[-1]) + len(match[-1])]
    # 清理文书html标签
    regHtml = '["“]?<(html|meta|style|title|h1|h2|h3|h4|h5|link'
    regHtml += '|script|head|body|div).*?>["”]?'
    rawdata = re.sub(regHtml, '', rawdata)
    # 清理空行
    rawdata = re.sub('\n\s*\n', '\n', rawdata)
    # 清理文书首行 法院和判决书在同一行的情况
    rawdataArr = rawdata.split('\n')
    for i in range(len(rawdataArr)):
        if i > 3:
            break
        match = re.search(
            '(.*法 *院).*((行 *政|刑 *事|民 *事).*(判 *决 *书|裁 *定 *书))', rawdataArr[i])
        if match:
            court = match.group(1)
            court = re.sub(' *', '', court)
            txtType = match.group(2)
            txtType = re.sub(' *', '', txtType)
            replace = court + '\n' + txtType
            rawdata = re.sub(
                '(.*法 *院).*((行 *政|刑 *事|民 *事).*(判 *决 *书|裁 *定 *书))',
                replace, rawdata)
            break
    return rawdata


def clean_num(anhao):
    """案号清洗."""
    anhao = anhao.strip()
    anhao = re.sub(
        '(第|字|执|申|初|再|终|恢|保|审|更|特)0+([\d一\-－、\-]+号)', r'\1\2', anhao)
    anhao = re.sub('[（\[【〔]', '(', anhao)
    anhao = re.sub('[）\]】〕]', ')', anhao)
    anhao = re.sub('—+', '-', anhao)
    if not anhao.startswith('('):
        anhao = re.sub('(\d{4})年?(.*)', r'(\1)\2', anhao)
    return anhao



"""."""
import json
import logging
import os
import logging.config


def setup_logging(
        default_path='logging.json',
        default_level=logging.INFO,
        env_key='LOG_CFG'):
    """Setup logging configuration."""
    path = default_path
    value = os.getenv(env_key, None)
    if value:
        path = value
    # path = os.path.dirname(os.path.abspath(__file__)) + path
    print(path)
    print('是否找到日志配置文件,%s' % os.path.exists(path))
    if os.path.exists(path):
        with open(path, 'rt') as f:
            config = json.load(f)
        logging.config.dictConfig(config)
    else:
        logging.basicConfig(level=default_level)



"""在判决结果截断的基础上对判决结果进行提取."""
import re


class Judgement(object):
    """docstring for ."""

    def __init__(self):
        """."""
        self.ANHAO = "(撤销|维持|变更).*([\(\[（【〔（]\d{4}[\)\]】〕）]"
        self.ANHAO += "\w+(初|终)\w+[\d、\-—]+号).*(判决|裁定)"
        self.regRuleFirCivil = []
        self.regRuleFirAdmini = []
        self.regRuleFirCriminal = []
        self.regRuleSecCivil = []
        self.regRuleSecAdmini = []
        self.regRuleSecCriminal = []
        self.regRuleReCivil = []
        self.regRuleReAdmini = []
        self.regRuleReCriminal = []
        self.regJudgeFirCivil = []        # 民事一审判定书
        self.regJudgeFirAdmini = []       # 行政一审判定书
        self.regJudgeFirCriminal = []     # 刑事一审判定书
        self.regJudgeSecCivil = []        # 民事二审判定书
        self.regJudgeSecAdmini = []       # 行政二审判定书
        self.regJudgeSecCriminal = []     # 刑事二审判定书
        self.regJudgeReCivil = []         # 民事再审判定书
        self.regJudgeReAdmini = []        # 行政再审判定书
        self.regJudgeReCriminal = []      # 刑事再审判定书

    def generate_judgement_cd(self, law_entity, level, item):
        """裁定书."""
        offen, denfen = self.parse_rule(law_entity, item, level)
        return offen, denfen

    def generate_judgement_pj(self, law_entity, level, results):
        """判决书."""
        offen, denfen = self.parse_judge(law_entity, results, level)
        return offen, denfen

    def parse_rule(self, law_entity, line, resulttype):
        """裁定书的判决结果提取."""
        offen = 0
        denfen = 0
        regRule = []
        if law_entity.level_ == '一审' and law_entity.nature_ == '民事':
            regRule = self.regRuleFirCivil
        elif law_entity.level_ == '一审' and law_entity.nature_ == '行政':
            regRule = self.regRuleFirAdmini
        elif law_entity.level_ == '一审' and law_entity.nature_ == '刑事':
            regRule = self.regRuleFirCriminal
        elif law_entity.level_ == '二审' and law_entity.nature_ == '民事':
            regRule = self.regRuleSecCivil
        elif law_entity.level_ == '二审' and law_entity.nature_ == '行政':
            regRule = self.regRuleSecAdmini
        elif law_entity.level_ == '二审' and law_entity.nature_ == '刑事':
            regRule = self.regRuleSecCriminal
        elif law_entity.level_ == '再审' and law_entity.nature_ == '民事':
            regRule = self.regRuleReCivil
        elif law_entity.level_ == '再审' and law_entity.nature_ == '行政':
            regRule = self.regRuleReAdmini
        elif law_entity.level_ == '再审' and law_entity.nature_ == '刑事':
            regRule = self.regRuleReCriminal
        if line.find('反诉') >= 0 and law_entity.nature_ == '民事'\
                and law_entity.level_ == '一审':
            return -1, -1
        for reg in regRule:
            if reg[3] == resulttype and re.search(reg[0], line):
                offen = reg[1]
                denfen = reg[2]
                break
        return offen, denfen

    def parse_judge(self, law_entity, results, resulttype):
        """判决书的判决结果提取."""
        offen = 0
        denfen = 0
        regList = []
        if law_entity.level_ == '一审' and law_entity.nature_ == '民事':
            regList = self.regJudgeFirCivil
        elif law_entity.level_ == '一审' and law_entity.nature_ == '行政':
            regList = self.regJudgeFirAdmini
        elif law_entity.level_ == '一审' and law_entity.nature_ == '刑事':
            regList = self.regJudgeFirCriminal
        elif law_entity.level_ == '二审' and law_entity.nature_ == '民事':
            regList = self.regJudgeSecCivil
        elif law_entity.level_ == '二审' and law_entity.nature_ == '行政':
            regList = self.regJudgeSecAdmini
        elif law_entity.level_ == '二审' and law_entity.nature_ == '刑事':
            regList = self.regJudgeSecCriminal
        elif law_entity.level_ == '再审' and law_entity.nature_ == '民事':
            regList = self.regJudgeReCivil
        elif law_entity.level_ == '再审' and law_entity.nature_ == '行政':
            regList = self.regJudgeReAdmini
        elif law_entity.level_ == '再审' and law_entity.nature_ == '刑事':
            regList = self.regJudgeReCriminal
        for line in results:
            if line.find('反诉') >= 0 and law_entity.nature_ == '民事'\
                    and law_entity.level_ == '一审':
                return -1, -1
            for reg in regList:
                if reg[3] == resulttype and re.search(reg[0], line):
                    if reg[1]:
                        offen = 1
                    if reg[2]:
                        denfen = 1
                    break
        return offen, denfen

    def parse_pre(self, judge, txt):
        """提取历审案号和判决结果以及文书类型."""
        if judge.trial_level_ == '二审':
            match = re.search(self.ANHAO, txt)
            if match:
                judge.firjudgement_ = match.group(1)
                judge.fircasenum_ = match.group(2)
                judge.firitype_ = match.group(4)
        elif judge.trial_level_ == '再审':
            print(re.findall(self.ANHAO, txt))
            for match in re.findall(self.ANHAO, txt):
                if "终" in match[2]:
                    judge.secjudgement_ = match[0]
                    judge.seccasenum_ = match[1]
                    judge.secitype_ = match[3]
                elif "初" in match[2]:
                    judge.firjudgement_ = match[0]
                    judge.fircasenum_ = match[1]
                    judge.firitype_ = match[3]

    def parse_administrative(self, judge, txt):
        """解析行政文书号和判决结果."""
        match = re.search(
            '[0-9]*号?.*((重新)(作出)?.*(争议|复审|无效)?.*(决定|裁定|申请))', txt)
        if match:
            judge.administrative_judgement_ = match.group(2)
            judge.administrative_ = re.sub(match.group(2), '', match.group(1))
            return
        match = re.search(
            '(重新|维持|撤销|变更).*?((商评字|[\[〔［][0-9]{4}[］〕\]]|第?[0-9]+号?)\
            .*(争议|无效|无效宣告|驳回复审|复审|审查|争议).*(决定|裁定|申请|裁定)书?》?)', txt)
        if match:
            judge.administrative_judgement_ = match.group(1)
            judge.administrative_ = match.group(2)
            return
        match = re.search(
            '([0-9]*\.[0-9xX].*(无效|争议|复审).*(决定|裁定|申请)).*((重新)(作出)?)', txt)
        if match:
            judge.administrative_judgement_ = match.group(5)
            judge.administrative_ = match.group(1)
            return



"""."""
import re
import os


def get_law(line):
    """针对单个文书的法条提取，整合进入库的方法."""
    ABSPATH = os.path.abspath(__file__)
    ABSPATH = os.path.dirname(ABSPATH) + "/"
    regList = get_txt(ABSPATH + 'config/article_standardization.txt')
    reList = re.findall(r'((?:\d{4}年)?《.*?》[^。；《]*)', line)
    lawArticle = set()
    for s in reList:
        resub = re.search(r'(?:.*《.*?》.*[条款项目]*)', s)  # 省去了编章节
        if not resub:
            continue
        article = resub.group(0)
        lawTxt = re.search(r"《.*?》", article).group(0)
        lawResp = re.search(r'.*《.*?》', article)
        law = lawResp.group(0)
        articleResp = re.findall(r'第\w*?条', article)
        lawStandar = standardlized(regList, lawTxt)
        if articleResp and lawStandar:
            for item in articleResp:
                itemSub = re.search(r'%s[^条]*[款项目]' % item, article)
                if itemSub:
                    lawStandar = re.sub(
                        r'《.*?》', '《' + lawStandar + '》',
                        law + itemSub.group(0))
                    lawArticle.add(lawStandar)
                else:
                    lawStandar = re.sub(r'《.*?》', '《' + lawStandar + '》', law)
                    lawArticle.add(lawStandar)
        elif lawStandar:
            lawArticle.add(lawStandar)
    return lawArticle


def standardlized(regList, lawTxt):
    """."""
    for regTuple in regList:
        reg = regTuple[0]
        match = re.search(r'%s' % reg, lawTxt)
        if match:
            lawStandar = regTuple[1]
            return lawStandar


def parse_content(id, content):
    """提取文本数据."""
    sContent = re.split(r'\s+本院认为', content)
    returnList = []
    for i in range(len(sContent)):
        dic = {}
        # 编章节条款项目
        reList = re.findall(r'((?:\d{4}年)?《.*?》[^。；《]*)', sContent[i])
        resultList = []
        for s in reList:
            resub = re.search(r'(?:.*[编章节条款项目]+)', s)
            if resub is None:
                resub = re.search(r'.*《.*》', s)
            if resub is not None:
                resultList.append(resub.group(0))
        if resultList is not None and len(resultList) > 0:
            dic['id'] = id
            dic['type'] = i
            dic['articles'] = resultList
            returnList.append(dic)
    return returnList


def parse_record(result):
    """解析结果集."""
    parseResults = []
    for record in result:
        id = record[0]
        content = record[1]
        if content is not None and content != '':
            returnList = parse_content(id, content)
            parseResults.extend(returnList)
    return parseResults


def parseArticle(article):
    """法条分割。例如：《?》第x条，第y条-->《?》第x条  《?》第y条."""
    lawResp = re.search(r'《.*?》', article)
    if lawResp is None:
        return None, None
    law = lawResp.group(0)
    articleResp = re.findall(r'第\w*?条', article)
    if articleResp is None:
        return None, None
    returnList = []
    for item in articleResp:
        itemSub = re.search(r'%s[^条]*[款项目]' % item, article)
        if itemSub is None:
            returnList.append(item)
        else:
            returnList.append(itemSub.group(0))
    return law, returnList


def get_txt(fileName):
    """."""
    txt = open(fileName)
    cList = []
    for line in txt:
        cArray = line.split("——>")
        cTuple = (cArray[0].strip(), cArray[1].strip())
        cList.append(cTuple)
    return cList


def standardizedArticle(article1, article2, regList):
    """标准化法条."""
    for regTuple in regList:
        reg = regTuple[0]
        match = re.search(r'%s' % reg, article2)
        if match is not None:
            article3 = regTuple[1]
            article3 = re.sub(r'《.*?》', '《' + article3 + '》', article1)
            return article3
    return None


def extractLaw(article):
    """提取书名号内的内容."""
    law = ''
    if article is not None:
        law = re.search(r"《.*?》", article).group(0)
    return law


def extract_detail(content):
    """."""
    law = re.search('《(.*?)》', content)
    if law:
        law = law.group(1)
        article = re.search('》\)?）?第?(.*?)条', content)
        if article:
            article = article.group(1)
            content = re.sub('》\)?）?第?(.*?)条', '》', content)
        paragraph = re.search('》第?(.*?)款', content)
        if paragraph:
            paragraph = paragraph.group(1)
            content = re.sub('》第?(.*?)款', '》', content)
        item = re.search('》第?(.*?)项', content)
        if item:
            item = item.group(1)
        return law, converter(article), converter(paragraph), converter(item)
    else:
        return None, None, None, None


def converter(number):
    """."""
    if not number:
        return ''
    number = re.sub(r'\(|（|\)|）', '', number)
    if len(number) < 1:
        return ''
    if number.isdigit():
        return number
    dic = {
            '零': '0', '一': '1', '二': '2', '三': '3', '四': '4',
            '五': '5', '六': '6', '七': '7', '八': '8', '九': '9',
            '十': '10', '百': '100'}
    dnum = ''
    if number[0] == '十':
        number = '一' + number
    if number[len(number) - 1] == '十':
        number = number + '零'
    if number[len(number) - 1] == '百':
        number = number + '零' + '零'
    for d in number:
        if d not in dic.keys():
            return None
        if d != '百' and d != '十':
            dnum = dnum + dic.get(d)
    return dnum



  # -*- coding: utf-8 -*-
"""
Created on Tue May  9 14:33:18 2017

@author: Administrator
"""
import re

# 返回专利复审委决定号
def patent_review(line):
    reViewSet = set()
    match = re.findall("(第|作出的)([0-9]+)(号)\w*(无效宣告|无效决定|复审请求)",line)
    for m in match:
        reView = m[1]
        if '无效' in m[3]:
            judgeType = '无效'
        elif '复审' in m[3]:
            judgeType = '复审'
        reViewSet.add((reView, judgeType))
    return reViewSet

# 返回商标评审委文书号
def trademark_review(line):
    reViewSet = set()
    match = re.findall("(商评字)([^\r\n\t。；:；:号第]{,6}[\r\n\t]{,1}[第]{,1}[^0-9。；:]{,3})([0-9０－９]+)(号)?",line)
    for m in match:
        reViewSet.add("".join(m))
    return reViewSet



"""文书信息挖掘主文件."""
import collections
import jieba
from .entity import LawEntity
from .main_tool import clean, get_next_line2, load_dict
from .main_parse import process_title, process_type, process_number, \
    extract_relative_person, parse_cause, parse_content
from .ronghui.Money.AllMoney import Get_Appeal_Judge_Money


def main_extract(file_path):
    """主入口函数."""
    rawdata = clean(file_path)
    return rawdata, extract_from_rawdata(rawdata)


def extract_from_rawdata(rawdata):
    """副入口函数."""
    data_generator = get_next_line2(rawdata)
    law_entity = extract_main(data_generator)
    return law_entity


def extract_main(data_generator):
    """主文提取."""
    load_dict()
    # 自定义分词样本，法院
    jieba.load_userdict("config/self_dict.txt")
    jieba.initialize()
    law_entity = LawEntity()
    relative_person_list = collections.OrderedDict()
    line, raw_line = next(data_generator)
    if line[-1:] == '书':
        law_entity.title_ = line  # 文书标题
        line, raw_line = next(data_generator)
    # 法院名称, 法院级别, 涉案地区, 是否涉外
    line, raw_lines = process_title(line, law_entity, data_generator)
    # 文书类型,案件性质
    line, raw_lines = process_type(line, law_entity, data_generator)
    # 案号
    line, raw_lines = process_number(line, law_entity, data_generator)
    # PARTIES = ["原告", "被告", "上诉人", "被上诉人", "第三人"]
    line, raw_line = extract_relative_person(
        line, law_entity, data_generator, relative_person_list)
    # for pp in relative_person_list:
    #     print(relative_person_list[pp])
    #     for rp in relative_person_list[pp]:
    #         print(rp.relative_)
    # 正文
    #     案由
    parse_cause(line, law_entity)
    #     专利号 抽取专利复审委的文书号 抽取商标号 抽取商标评审委的文书号 摘要 判决结果
    patentNumber = set()
    trademarkNumber = set()
    line, raw_line = parse_content(
        line, law_entity, data_generator, patentNumber, trademarkNumber)
    for role, role_list in relative_person_list.items():
        law_entity.party_.extend(role_list)
    # print(law_entity.judge_results_)
    return law_entity


if __name__ == '__main__':
    filePath = '/home/jokers/python/projects/_file/广知/5.txt'
    rawdata, law_entity = main_extract(filePath)
    print(law_entity)
    Get_Appeal_Judge_Money(law_entity, rawdata)
    print(law_entity.judge_money)
    print(law_entity.appeal_money)



"""."""
from distutils.core import setup

setup(name='zcb_gz',
      version='1.1',
      author='Jokers',
      author_email='hlxstc680@gmail.com',
      url='https://www.python.org/jokers/distutils-sig/',
      packages=[
        'zcb_gz', 'zcb_gz.jokers', 'zcb_gz.ronghui',
        'zcb_gz.ronghui.Money'],
      )



"""自定义字典."""


class Dict:
    """字典."""

    def __init__(self, name, path):
        """."""
        self.name_ = name
        self.path_ = path
        self.content_ = set()
        self.kvs = {}

    def load_dict(self):
        """."""
        pass


class NationalDict(Dict):
    """."""

    def __init__(self, name, path):
        """."""
        Dict.__init__(self, name, path)

    def load_dict(self):
        """."""
        with open(self.path_, "r") as f:
            lines = f.readlines()
            for line in lines:
                line = line.strip()
                if not line:
                    continue
                self.content_.add(line)


class AddressDict(Dict):
    """."""

    def __init__(self, name, path):
        """."""
        Dict.__init__(self, name, path)

    def load_dict(self):
        """."""
        with open(self.path_, "r") as f:
            lines = f.readlines()
            for line in lines:
                line = line.strip()
                if not line:
                    continue
                tokens = line.split("\t")
                if len(tokens) != 2:
                    continue
                self.kvs[tokens[0]] = tokens[1]
